"""Path input to enter a path value."""

# Import third-party modules
try:
    from PySide import QtCore
    from PySide import QtGui
    from PySide import QtGui as QtWidgets
except ImportError as error:
    from PySide2 import QtCore
    from PySide2 import QtGui
    from PySide2 import QtWidgets

# Import local modules
from smartEdit.mvc import gui_helper
from smartEdit.widgets.stringinput import Stringinput


class Pathinput(Stringinput):
    """Path input to enter a path value."""

    def create_widgets(self):
        """Create widgets."""
        super(Pathinput, self).create_widgets()

        self.folder = QtWidgets.QToolButton()
        gui_helper.set_icon(self.folder, self.icons["folder"])

    def create_layouts(self):
        """Create layouts."""
        super(Pathinput, self).create_layouts()

        self.layout_main.addWidget(self.folder)

    def create_signals(self):
        """Create signals."""
        super(Pathinput, self).create_signals()

        self.folder.clicked.connect(lambda: self.show_browser())

    def update(self):
        """Update the node's dropdown to the currently selected value."""
        self.knob.setValue(self.input.text())

    def show_browser(self):
        """Show browser to navigate to a file and set up input to this path."""
        path, _ = QtWidgets.QFileDialog.getOpenFileName(self, "Browse file")
        self.input.setText(path)
